## request_extras.



Request extras is a simple library that contains extension methods for dealing Dart [HttpRequest](https://api.dartlang.org/stable/2.5.2/dart-io/HttpRequest-class.html) objects.

For now the library mainly focuses on simplifying the usage of getters and setters on  [headers](https://api.dartlang.org/stable/2.5.2/dart-io/HttpRequest/headers.html)  property by transforming [HttpHeaders.value](https://api.dartlang.org/stable/2.5.2/dart-io/HttpHeaders/value.html) and [HttpHeaders.set](https://api.dartlang.org/stable/2.5.2/dart-io/HttpHeaders/set.html)  calls into getters and setter that exist directly on the [HttpRequest](https://api.dartlang.org/stable/2.5.2/dart-io/HttpRequest-class.html) object. All staticly typed, and without having to specify the names of unsupported headers as strings!

In total, there are 10 different extension exported, each extension deals with a different header type that correspond to Http headers as documented on [MDN](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers).

[license](https://github.com/dart-lang/stagehand/blob/master/LICENSE).

## Usage

A simple usage example:

```dart
import 'dart:io';

/// Lets import some headers extensions.
import 'package:request_extras/request_extras.dart' show ProxyHeaders, SecurityHeaders;

main() {
  HttpRequest request;
  
  // Here's how you'd normally have to deal with HttpRequest headers using the Dart Sdk.
  /// Getting and setting a header not included in the SDK.
  const myHeaderName = 'X-Forwarded-For';
  final xForwardFor = request.headers.value(myHeaderName);
  request.headers.set(myHeaderName, 'some header value');
  
  /// Getting and setting a header that IS included in the Dart SDK.
  final host = request.headers.value(HttpHeaders.hostHeader);
  request.headers.set(HttpHeaders.hostHeader, 'some header value');
  
  /// This can be simplified by using request extras.
  final clientIp = request.xClientIpHeader;
  request.xClientIpHeader = 'Some Value';
  final corsPolicy = request.crossOriginOpenerPolicyHeader;
  request.crossOriginOpenerPolicyHeader = 'Some Cors Policy';
}
```

## Features and bugs

Please file feature requests and bugs at the [issue tracker][tracker].

[tracker]: http://example.com/issues/replaceme
